summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorNils Philippsen <nils@tiptoe.de>2017-08-05 13:31:06 +0200
committerNils Philippsen <nils@tiptoe.de>2017-08-05 13:31:06 +0200
commit7765724d51f78690c814eda6533fc0ac81ca9077 (patch)
tree1a8329e5be204b76789654833dfc77181cf07ad5 /lib
parentde1f8f8345ecd6af0ec1177703465e9471cfe862 (diff)
downloadsqlalchemy-7765724d51f78690c814eda6533fc0ac81ca9077.tar.gz
fix "constrast" typos
Diffstat (limited to 'lib')
-rw-r--r--lib/sqlalchemy/orm/events.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/sqlalchemy/orm/events.py b/lib/sqlalchemy/orm/events.py
index 1d1c347b1..6c7b87bfd 100644
--- a/lib/sqlalchemy/orm/events.py
+++ b/lib/sqlalchemy/orm/events.py
@@ -727,7 +727,7 @@ class MapperEvents(event.Events):
def go():
# ...
Constrast this event to :meth:`.MapperEvents.after_configured`,
which is invoked after the series of mappers has been configured,
as well as :meth:`.MapperEvents.mapper_configured`, which is invoked
on a per-mapper basis as each one is configured to the extent possible.
@@ -774,7 +774,7 @@ class MapperEvents(event.Events):
operation proceeds; unlike that event, when this event is invoked,
all cross-configurations (e.g. backrefs) will also have been made
available for any mappers that were pending.
- Also constrast to :meth:`.MapperEvents.before_configured`,
+ Also contrast to :meth:`.MapperEvents.before_configured`,
which is invoked before the series of mappers has been configured.
This event can **only** be applied to the :class:`.Mapper` class
@@ -727,7 +727,7 @@ class MapperEvents(event.Events):
def go():
# ...
- Constrast this event to :meth:`.MapperEvents.after_configured`,
+ Contrast this event to :meth:`.MapperEvents.after_configured`,
which is invoked after the series of mappers has been configured,
as well as :meth:`.MapperEvents.mapper_configured`, which is invoked